@@ -7,7 +7,8 @@
 
 extern crate alloc;
 
-mod iface;
 mod phy;
 
-pub use iface::Interface as SlipInterface;
+pub use embedded_hal;
+pub use phy::SlipDevice;
+pub use smoltcp;
